unit Main;

interface

uses
  System.SysUtils, System.Types, System.UITypes, System.Classes, System.Variants, 
  FMX.Types, FMX.Graphics, FMX.Controls, FMX.Forms, FMX.Dialogs, FMX.StdCtrls, FMX.Layouts, FMX.Memo, FMX.Objects;

type
  TfmMainSampleTLang = class(TForm)
    Label1: TLabel;
    btnEn: TButton;
    btnDe: TButton;
    btnFr: TButton;
    Text1: TText;
    Button1: TButton;
    Label2: TLabel;
    btnZn: TButton;
    Lang1: TLang;
    Text2: TText;
    procedure btnDeClick(Sender: TObject);
    procedure btnFrClick(Sender: TObject);
    procedure btnEnClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure btnZnClick(Sender: TObject);
  private
    procedure ChangeLanguageP(sNew: string);
  public
    function sTextManualF(sOrg:string): string;
  end;

var
  fmMainSampleTLang: TfmMainSampleTLang;

implementation

{$R *.fmx}

const
  cTxtMan = 'This text is translated manual';
  cTxtFail = 'This text can''t be translated';

procedure TfmMainSampleTLang.FormCreate(Sender: TObject);
begin
  Text1.Text := cTxtMan;
  Text2.Text := cTxtFail;
  // force translation at startup, to ensure, also manual texts are translated
  ChangeLanguageP(Lang1.Lang);
end;

function TfmMainSampleTLang.sTextManualF(sOrg: string): string;
// translate a text, which is not in the automate translation process of TFmxObjects
begin
  // first check, if the selected language has a mapping
  if Lang1.Resources.IndexOf(Lang1.Lang)>=0 then begin
    // get the resource stringlist of the current language and get the translation
    result := Lang1.LangStr[Lang1.Lang].Values[sOrg];
    if result='' then begin
      // text not found in mapping - keep original text
      result := sOrg;
    end;
  end
  else begin
    // language not found: must be the default language
    result := sOrg;
  end;
end;

procedure TfmMainSampleTLang.ChangeLanguageP(sNew:string);
begin
  Lang1.Lang := sNew;
  // do some manual text translations - not done by delphi
  Text1.Text := sTextManualF(cTxtMan);
  Text2.Text := sTextManualF(cTxtFail);
end;

procedure TfmMainSampleTLang.btnDeClick(Sender: TObject);
begin
  ChangeLanguageP('de');
end;

procedure TfmMainSampleTLang.btnEnClick(Sender: TObject);
begin
  ChangeLanguageP('en');
end;

procedure TfmMainSampleTLang.btnFrClick(Sender: TObject);
begin
  ChangeLanguageP('fr');
end;

procedure TfmMainSampleTLang.btnZnClick(Sender: TObject);
begin
  ChangeLanguageP('zn');
end;

end.
